@@ -1,45 +1,39 @@
 package POD2::RU;
 
 # ABSTRACT: Perl Документация по-русски
-use utf8;
-use strict;
 use warnings;
-use base 'Exporter';
+use strict;
+
+use utf8;
 use base 'POD2::Base';
 
-#use IO::Interactive qw(is_interactive);
-use Encode::Locale qw(decode_argv);
-
-use 5.008_005;
-our $VERSION = '5.18.0.1.64';
-
-our @EXPORT_OK = qw(print_pod print_pods);
+our $VERSION = '5.18.0.1.65';
 
 # Versions list
 sub pod_info {
-    return {
-        perl            => '5.18.0.1',
-        perlintro       => '5.18.0.1',
-        perlrun         => '5.18.0.1',
-        a2p             => '5.18.0.1',
-        perlbook        => '5.18.0.1',
-        perldoc         => '5.18.0.1',
-        perlpragma      => '5.18.0.1',
-        perlstyle       => '5.18.0.1',
-        perlcheat       => '5.18.0.1',
-        perlnewmod      => '5.18.0.1',
-        perlrequick     => '5.18.0.1',
-        perlreref       => '5.18.0.1',
-        perlunicode     => '5.18.0.1',
-        perlretut       => '5.18.0.1',
-        perlreguts      => '5.18.0.1',
-        perlrecharclass => '5.18.0.1',
-        perlrebackslash => '5.18.0.1',
-        perlreapi       => '5.18.0.1',
-        perlre          => '5.18.0.1',
-        perlsecret      => '5.18.0.1',
-        perlreapi       => '5.18.0.1',
-    };
+    perl              => '5.18.0.1',
+      perlintro       => '5.18.0.1',
+      perlrun         => '5.18.0.1',
+      a2p             => '5.18.0.1',
+      perlbook        => '5.18.0.1',
+      perldoc         => '5.18.0.1',
+      perlpragma      => '5.18.0.1',
+      perlstyle       => '5.18.0.1',
+      perlcheat       => '5.18.0.1',
+      perlnewmod      => '5.18.0.1',
+      perlrequick     => '5.18.0.1',
+      perlreref       => '5.18.0.1',
+      perlunicode     => '5.18.0.1',
+      perlretut       => '5.18.0.1',
+      perlreguts      => '5.18.0.1',
+      perlrecharclass => '5.18.0.1',
+      perlrebackslash => '5.18.0.1',
+      perlreapi       => '5.18.0.1',
+      perlre          => '5.18.0.1',
+      perlsecret      => '5.18.0.1',
+      perlreapi       => '5.18.0.1',
+      perlglossary    => '5.18.0.1', #для будущего перевода
+      ;
 }
 
 # String for perldoc with -L switch
@@ -47,48 +41,6 @@ sub search_perlfunc_re {
     return 'Список функций Perl';
 }
 
-# Print information about a pod file
-sub print_pod {
-    my ( $self, @tmp_args ) = @_;
-    my @args = @tmp_args;    # ? @tmp_args : @ARGV;
-    prepare_encoding_console();
-    my $pods = $self->pod_info;
-
-    while (@args) {
-        ( my $pod = lc shift @args ) =~ s/[.]pod$//smx;
-        if ( exists $pods->{$pod} ) {
-            print
-qq{\t'$pod' переведен на русский Perl $pods->{$pod}\n};
-        }
-        else {
-            print qq{\t'$pod' еще не переведен\n};
-        }
-    }
-    return 1;
-}
-
-# Print list of translated pods
-sub print_pods {
-    my $self = shift;
-
-    #$self = $self ? $self : __PACKAGE__;
-    prepare_encoding_console();
-    $self->SUPER::print_pods;
-    return 1;
-}
-
-sub prepare_encoding_console {
-
-    #    if ( is_interactive() ) {
-    binmode STDIN,  ':encoding(console_in)';
-    binmode STDOUT, ':encoding(console_out)';
-    binmode STDERR, ':encoding(console_out)';
-
-    #    }
-    Encode::Locale::decode_argv();
-    return 1;
-}
-
 1;
 __END__
 
@@ -98,7 +50,7 @@ __END__
 
 =head1 NAME
 
-POD2::RU - Perl Документация по-русски
+POD2::RU - документация Perl по-русски
 
 =for HTML 
 <a href="https://travis-ci.org/mishin/POD-to-RU"><img src="https://travis-ci.org/mishin/POD-to-RU.svg?branch=master"></a>
@@ -194,7 +146,7 @@ C<<pod_info>> - Выдает хэш с текущими pod файлами в д
 
 =head1 AUTHOR
 
-Nikolay Mishin E<lt>mi@ya.ru<gt>
+Nikolay Mishin E<lt> >mi@ya.ru E<gt>
 
 =head1 CONTRIBUTORS
 
@@ -237,14 +189,18 @@ Copyright 2015- Nikolay Mishin
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 REPOSITORY
+
+L<https://github.com/mishin/POD-to-RU>
+
 =head1 SEE ALSO
 
 L<POD2::ES>, L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>.
 
 =head1 DONATIONS
 
-Проект перевода документации Perl требует постоянных усилий, что доступно только для сильных духов и альтруистов.
-Авторы не просят, но ни не отвергают помощь в виде денег, книг, сыра и продуктов из свинины (можно хамон;) ), или даже поездки в Полинезию для снижения утомления и сохранения боевого духа команды. Мы приглашаем всех.
+Проект перевода документации Perl требует постоянных усилий, что доступно только для сильных духом и альтруистов.
+Авторы не просят, но ни не отвергают помощь в виде денег, книг, сыра и продуктов из свинины (можно хамон;) ), или даже поездки в Полинезию для снижения утомления и сохранения боевого духа команды. Мы приглашаем всех. (стащено и переведено отсюда L<POD2::ES>)
 
 =head1 THANKS 
 
